@@ -560,7 +560,7 @@ namespace mfront {
       }
     }
     this->writeInterfaceSpecificVariables(os, mpd);
-    if (!mpd.inputs.empty()) {
+    if ((!areRuntimeChecksDisabled(mpd)) && (!mpd.inputs.empty())) {
       os << "#ifndef MFRONT_NOERRNO_HANDLING\n"
          << "const auto mfront_errno_old = errno;\n"
          << "errno=0;\n"
@@ -569,34 +569,36 @@ namespace mfront {
     os << "auto " << mpd.output.name << " = " << mpd.output.type << "{};\n";
     this->writeCxxTryBlock(os);
     os << mpd.f.body << "\n";
-    // checking the bounds and physical bounds of the output
-    if ((mpd.output.hasBounds()) || (mpd.output.hasPhysicalBounds())) {
-      const auto cast_start = useQuantities(mpd) ? mpd.output.type + "(" : "";
-      const auto cast_end = useQuantities(mpd) ? ")" : "";
-      if (mpd.output.hasPhysicalBounds()) {
-        const auto b = mpd.output.getPhysicalBounds();
-        if (b.boundsType == VariableBoundsDescription::LOWER) {
-          os << "if(" << mpd.output.name << " < " << cast_start << b.lowerBound
-             << cast_end << "){\n"
-             << "return std::nan(\"\");\n"
-             << "}\n";
-        } else if (b.boundsType == VariableBoundsDescription::UPPER) {
-          os << "if(" << mpd.output.name << " > " << cast_start << b.upperBound
-             << cast_end << "){\n"
-             << "return std::nan(\"\");\n"
-             << "}\n";
-        } else {
-          os << "if((" << mpd.output.name << " < " << cast_start << b.lowerBound
-             << cast_end << ")||"
-             << "(" << mpd.output.name << " > " << cast_start << b.upperBound
-             << cast_end << ")){\n"
-             << "return std::nan(\"\");\n"
-             << "}\n";
+    if (!areRuntimeChecksDisabled(mpd)) {
+      // checking the bounds and physical bounds of the output
+      if ((mpd.output.hasBounds()) || (mpd.output.hasPhysicalBounds())) {
+        const auto cast_start = useQuantities(mpd) ? mpd.output.type + "(" : "";
+        const auto cast_end = useQuantities(mpd) ? ")" : "";
+        if (mpd.output.hasPhysicalBounds()) {
+          const auto b = mpd.output.getPhysicalBounds();
+          if (b.boundsType == VariableBoundsDescription::LOWER) {
+            os << "if(" << mpd.output.name << " < " << cast_start
+               << b.lowerBound << cast_end << "){\n"
+               << "return std::nan(\"\");\n"
+               << "}\n";
+          } else if (b.boundsType == VariableBoundsDescription::UPPER) {
+            os << "if(" << mpd.output.name << " > " << cast_start
+               << b.upperBound << cast_end << "){\n"
+               << "return std::nan(\"\");\n"
+               << "}\n";
+          } else {
+            os << "if((" << mpd.output.name << " < " << cast_start
+               << b.lowerBound << cast_end << ")||"
+               << "(" << mpd.output.name << " > " << cast_start << b.upperBound
+               << cast_end << ")){\n"
+               << "return std::nan(\"\");\n"
+               << "}\n";
+          }
         }
       }
     }
     this->writeCxxCatchBlock(os, mpd, floating_point_type, use_qt);
-    if (!mpd.inputs.empty()) {
+    if ((!areRuntimeChecksDisabled(mpd)) && (!mpd.inputs.empty())) {
       os << "#ifndef MFRONT_NOERRNO_HANDLING\n";
       // can't use std::swap here as errno might be a macro
       os << "const auto mfront_errno = errno;\n"
@@ -629,13 +631,15 @@ namespace mfront {
     for (const auto& i : mpd.inputs) {
       os << "static_cast<void>(" << i.name << ");\n";
     }
-    if (hasPhysicalBounds(mpd.inputs)) {
-      os << "/* treating mpd.physical bounds */\n";
-      writePhysicalBounds(os, mpd);
-    }
-    if (hasBounds(mpd.inputs)) {
-      os << "/* treating standard bounds */\n";
-      writeBounds(os, mpd);
+    if (!areRuntimeChecksDisabled(mpd)) {
+      if (hasPhysicalBounds(mpd.inputs)) {
+        os << "/* treating mpd.physical bounds */\n";
+        writePhysicalBounds(os, mpd);
+      }
+      if (hasBounds(mpd.inputs)) {
+        os << "/* treating standard bounds */\n";
+        writeBounds(os, mpd);
+      }
     }
     os << "return 0;\n";
   }  // end of writeMaterialPropertyCheckBoundsBody
