@@ -547,25 +547,27 @@ namespace mtest {
     auto p = std::find(enames.begin(), enames.end(), n);
     if (p != enames.end()) {
       const auto pos = static_cast<unsigned short>(p - enames.begin());
-      return [pos](const CurrentState& s) { return s.e1[pos]; };
+      return [pos](const CurrentState& s) noexcept { return s.e1[pos]; };
     }
     const auto snames = b.getThermodynamicForcesComponents();
     p = std::find(snames.begin(), snames.end(), n);
     if (p != snames.end()) {
       const auto pos = static_cast<unsigned short>(p - snames.begin());
-      return [pos](const CurrentState& s) { return s.s1[pos]; };
+      return [pos](const CurrentState& s) noexcept { return s.s1[pos]; };
     }
     const auto isvnames = b.expandInternalStateVariablesNames();
     p = std::find(isvnames.begin(), isvnames.end(), n);
     if (p != isvnames.end()) {
       const auto pos = static_cast<unsigned short>(p - isvnames.begin());
-      return [pos](const CurrentState& s) { return s.iv1[pos]; };
+      return [pos](const CurrentState& s) noexcept { return s.iv1[pos]; };
     }
     const auto esvnames = b.getExternalStateVariablesNames();
     p = std::find(esvnames.begin(), esvnames.end(), n);
     if (p != esvnames.end()) {
       const auto pos = static_cast<unsigned short>(p - esvnames.begin());
-      return [pos](const CurrentState& s) { return s.esv0[pos] + s.desv[pos]; };
+      return [pos](const CurrentState& s) noexcept {
+        return s.esv0[pos] + s.desv[pos];
+      };
     }
     tfel::raise("buildValueExtractor: no variable name '" + n + "'");
   }  // end of buildValueExtractor
