@@ -1145,7 +1145,7 @@ namespace tfel::math {
              "Evaluator::treatGroup2: "
              "unterminated group (group began with '" +
                  s + "').");
-    return std::move(g);
+    return g;
   }  // end of treatGroup2
 
   std::vector<double>::size_type Evaluator::registerVariable(
@@ -1435,7 +1435,7 @@ namespace tfel::math {
       }
       pev->expr = this->expr->differentiate(pos, pev->variables);
     }
-    return std::move(pev);
+    return pev;
   }  // end of differentiate
 
   std::shared_ptr<tfel::math::parser::ExternalFunction>
@@ -1448,7 +1448,7 @@ namespace tfel::math {
     this->checkCyclicDependency();
     auto f = std::make_shared<Evaluator>(*this);
     f->expr = f->expr->resolveDependencies(f->variables);
-    return std::move(f);
+    return f;
   }  // end of resolveDependencies() const
 
   void Evaluator::removeDependencies() {
@@ -1523,7 +1523,7 @@ namespace tfel::math {
     pev->manager = this->manager;
     pev->expr = this->expr->createFunctionByChangingParametersIntoVariables(
         pev->variables, params, pev->positions);
-    return std::move(pev);
+    return pev;
   }  // end of createFunctionByChangingParametersIntoVariables
 
   void Evaluator::getParametersNames(std::set<std::string>& n) const {
