@@ -300,119 +300,144 @@ int main(const int argc, const char* const* const argv) {
   try {
 #endif /* __CYGWIN__ */
 
-    registerCallBack("--quiet-failure", [] { /*do nothing*/ },
-                     "quietly fails without error message");
-    registerCallBack("--compiler-flags", [] { compilerflags = true; },
-                     "return TFEL's recommended compiler flags.");
-    registerCallBack("--debug-flags", [] { debugflags = true; },
-                     "return flags adding debugging symbols.");
-    registerCallBack("--oflags0", [] { oflags0 = true; },
-                     "return tfel recommended optimisation "
-                     "flags without architecture specific flags.");
-    registerCallBack("--oflags", [] { oflags0 = oflags = true; },
-                     "return tfel recommended optimisation "
-                     "flags with architecture specific flags.");
-    registerCallBack("--oflags2", [] { oflags2 = true; },
-                     "return some aggressive optimisation flags, "
-                     "possibly at the expense of numerical precision. "
-                     "This shall be added to `--oflags` results.");
-    registerCallBack("--warning", [] { warning = true; },
-                     "return tfel recommended warnings.");
-    registerCallBack("--includes", [] { incs = true; },
-                     "return tfel include path.");
-    registerCallBack("--cppflags", [] { cppflags = true; },
-                     "return preprocessor flags.");
-    registerCallBack("--ldflags", [] { ldflags = true; },
-                     "return linking flags.");
+    registerCallBack(
+        "--quiet-failure", [] { /*do nothing*/ },
+        "quietly fails without error message");
+    registerCallBack(
+        "--compiler-flags", [] { compilerflags = true; },
+        "return TFEL's recommended compiler flags.");
+    registerCallBack(
+        "--debug-flags", [] { debugflags = true; },
+        "return flags adding debugging symbols.");
+    registerCallBack(
+        "--oflags0", [] { oflags0 = true; },
+        "return tfel recommended optimisation "
+        "flags without architecture specific flags.");
+    registerCallBack(
+        "--oflags", [] { oflags0 = oflags = true; },
+        "return tfel recommended optimisation "
+        "flags with architecture specific flags.");
+    registerCallBack(
+        "--oflags2", [] { oflags2 = true; },
+        "return some aggressive optimisation flags, "
+        "possibly at the expense of numerical precision. "
+        "This shall be added to `--oflags` results.");
+    registerCallBack(
+        "--warning", [] { warning = true; },
+        "return tfel recommended warnings.");
+    registerCallBack(
+        "--includes", [] { incs = true; }, "return tfel include path.");
+    registerCallBack(
+        "--cppflags", [] { cppflags = true; }, "return preprocessor flags.");
+    registerCallBack(
+        "--ldflags", [] { ldflags = true; }, "return linking flags.");
     registerCallBack("--libs", [] { ldflags = true; }, "return linking flags.");
-    registerCallBack("--include-path", [] { incspath = true; },
-                     "return the path to the `TFEL` headers.");
-    registerCallBack("--library-path", [] { libspath = true; },
-                     "return the path to the `TFEL` library.");
-    registerCallBack("--library-dependency", [] { libsdeps = true; },
-                     "return the dependencies of a `TFEL` library.");
+    registerCallBack(
+        "--include-path", [] { incspath = true; },
+        "return the path to the `TFEL` headers.");
+    registerCallBack(
+        "--library-path", [] { libspath = true; },
+        "return the path to the `TFEL` library.");
+    registerCallBack(
+        "--library-dependency", [] { libsdeps = true; },
+        "return the dependencies of a `TFEL` library.");
     registerCallBack("--help", &treatHelp, "print this help message.");
 #ifdef HAVE_CASTEM
-    registerCallBack("--castem", [] { castem = true; },
-                     "request flags for castem.");
+    registerCallBack(
+        "--castem", [] { castem = true; }, "request flags for castem.");
 #endif /* HAVE_CASTEM */
 #ifdef HAVE_ZMAT
     registerCallBack("--zmat", [] { zmat = true; }, "request flags for zmat.");
 #endif /* HAVE_ZMAT */
-    registerCallBack("--exceptions", [] { exceptions = true; },
-                     "request flags for TFELException.");
-    registerCallBack("--math", [] { math = exceptions = true; },
-                     "request flags for TFELMath.");
-    registerCallBack("--math-kriging",
-                     [] { mathKriging = math = exceptions = true; },
-                     "request flags for TFELMathKriging.");
-    registerCallBack("--math-cubic-spline",
-                     [] { mathCubicSpline = math = exceptions = true; },
-                     "request flags for TFELMathCubicSpline.");
-    registerCallBack("--math-parser",
-                     [] {
-                       math = exceptions = true;
-                       unicodeSupport = true;
-                       mathParser = mathKriging = true;
-                     },
-                     "request flags for TFELMathParser.");
-    registerCallBack("--tests", [] { tests = true; },
-                     "request flags for TFELTests.");
-    registerCallBack("--system", [] { lsystem = exceptions = true; },
-                     "request flags for TFELSystem.");
-    registerCallBack("--utilities", [] { utilities = true; },
-                     "request flags for TFELUtilities.");
-    registerCallBack("--unicode-support", [] { unicodeSupport = true; },
-                     "request flags for TFELUnicodeSupport.");
-    registerCallBack("--glossary", [] { glossary = true; },
-                     "request flags for TFELGlossary.");
-    registerCallBack("--material",
-                     [] {
-                       exceptions = numodis = true;
-                       material = utilities = math = true;
-                     },
-                     "request flags for TFELMaterial.");
-    registerCallBack("--numodis", [] { numodis = true; },
-                     "request flags for TFELNUMODIS.");
-    registerCallBack("--mfront-profiling", [] { mfront_profiling = true; },
-                     "request flags for libMFrontProfiling.");
-    registerCallBack("--all",
-                     [] {
-                       exceptions = math = numodis = material = true;
-                       utilities = glossary = lsystem = tests = true;
-                       unicodeSupport = true;
-                       mfront_profiling = true;
-                     },
-                     "request flags for all librairies.");
+    registerCallBack(
+        "--exceptions", [] { exceptions = true; },
+        "request flags for TFELException.");
+    registerCallBack(
+        "--math", [] { math = exceptions = true; },
+        "request flags for TFELMath.");
+    registerCallBack(
+        "--math-kriging", [] { mathKriging = math = exceptions = true; },
+        "request flags for TFELMathKriging.");
+    registerCallBack(
+        "--math-cubic-spline",
+        [] { mathCubicSpline = math = exceptions = true; },
+        "request flags for TFELMathCubicSpline.");
+    registerCallBack(
+        "--math-parser",
+        [] {
+          math = exceptions = true;
+          unicodeSupport = true;
+          mathParser = mathKriging = true;
+        },
+        "request flags for TFELMathParser.");
+    registerCallBack(
+        "--tests", [] { tests = true; }, "request flags for TFELTests.");
+    registerCallBack(
+        "--system", [] { lsystem = exceptions = true; },
+        "request flags for TFELSystem.");
+    registerCallBack(
+        "--utilities", [] { utilities = true; },
+        "request flags for TFELUtilities.");
+    registerCallBack(
+        "--unicode-support", [] { unicodeSupport = true; },
+        "request flags for TFELUnicodeSupport.");
+    registerCallBack(
+        "--glossary", [] { glossary = true; },
+        "request flags for TFELGlossary.");
+    registerCallBack(
+        "--material",
+        [] {
+          exceptions = numodis = true;
+          material = utilities = math = true;
+        },
+        "request flags for TFELMaterial.");
+    registerCallBack(
+        "--numodis", [] { numodis = true; }, "request flags for TFELNUMODIS.");
+    registerCallBack(
+        "--mfront-profiling", [] { mfront_profiling = true; },
+        "request flags for libMFrontProfiling.");
+    registerCallBack(
+        "--all",
+        [] {
+          exceptions = math = numodis = material = true;
+          utilities = glossary = lsystem = tests = true;
+          unicodeSupport = true;
+          mfront_profiling = true;
+        },
+        "request flags for all librairies.");
     registerCallBack("--version", &treatVersion,
                      "print tfel version and svn revision.");
-    registerCallBack("--major-number",
-                     [] {
-                       const auto v = tokenize(VERSION, '.');
-                       if (v.size() >= 1) {
-                         std::cout << v[0] << " ";
-                       }
-                     },
-                     "print tfel major version.");
-    registerCallBack("--minor-number",
-                     [] {
-                       const auto v = tokenize(VERSION, '.');
-                       if (v.size() >= 2) {
-                         std::cout << v[1] << " ";
-                       }
-                     },
-                     "print tfel minor version.");
-    registerCallBack("--revision-number",
-                     [] {
-                       const auto v = tokenize(VERSION, '.');
-                       if (v.size() >= 3) {
-                         std::cout << v[2] << " ";
-                       }
-                     },
-                     "print tfel revision version.");
-    registerCallBack("--cxx-standard", [] { std::cout << "17"; },
-                     "print the version of the C++ standard "
-                     "used to compile TFEL.");
+    registerCallBack(
+        "--major-number",
+        [] {
+          const auto v = tokenize(VERSION, '.');
+          if (v.size() >= 1) {
+            std::cout << v[0] << " ";
+          }
+        },
+        "print tfel major version.");
+    registerCallBack(
+        "--minor-number",
+        [] {
+          const auto v = tokenize(VERSION, '.');
+          if (v.size() >= 2) {
+            std::cout << v[1] << " ";
+          }
+        },
+        "print tfel minor version.");
+    registerCallBack(
+        "--revision-number",
+        [] {
+          const auto v = tokenize(VERSION, '.');
+          if (v.size() >= 3) {
+            std::cout << v[2] << " ";
+          }
+        },
+        "print tfel revision version.");
+    registerCallBack(
+        "--cxx-standard", [] { std::cout << "20"; },
+        "print the version of the C++ standard "
+        "used to compile TFEL.");
     registerCallBack("--licence", &treatLicences, "print TFEL licences.");
     registerCallBack(
         "--python-bindings-support",
@@ -439,9 +464,9 @@ int main(const int argc, const char* const* const argv) {
 #endif
         },
         "print if mandex support is enabled (display `true` or `false`).");
-    registerCallBack("--mfront-doc-has-standalone-option",
-                     [] { std::cout << "true "; },
-                     "print if mfront-doc has the standalone option");
+    registerCallBack(
+        "--mfront-doc-has-standalone-option", [] { std::cout << "true "; },
+        "print if mfront-doc has the standalone option");
 
     if (argc == 1) {
       treatHelp();
@@ -548,7 +573,7 @@ int main(const int argc, const char* const* const argv) {
         std::cout << cxx_standard << " ";
       } else {
 #if (defined __GNUC__) || (defined __clang__) || (defined __INTEL_COMPILER)
-        std::cout << "-std=c++17 ";
+        std::cout << "-std=c++20 ";
 #endif
       }
     }
